#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_BITWISE_NOTAND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_BITWISE_NOTAND_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/scalar/bitwise_notand.hpp>

#endif
